@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Mojolicious::Plugin::Pubsub;
 #ABSTRACT: Pubsub plugin for Mojolicious
-$Mojolicious::Plugin::Pubsub::VERSION = '0.005';
+$Mojolicious::Plugin::Pubsub::VERSION = '0.006';
 use Mojo::Base 'Mojolicious::Plugin';
 
 use Mojo::IOLoop;
@@ -213,17 +213,17 @@ Mojolicious::Plugin::Pubsub - Pubsub plugin for Mojolicious
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
   # Mojolicious
   my $pubsub = $app->plugin('Pubsub', { cb => sub { print "Message: $_[0]\n"; }, socket => 'myapp.pubsub', });
-  $app->publish("message");
+  $app->pubsub->publish("message");
   
   # Mojolicious::Lite
   my $pubsub = plugin Pubsub => { cb => sub { print "Message: $_[0]\n"; }, socket => 'myapp.pubsub', };
-  app->publish("message");
+  app->pubsub->publish("message");
 
 =head1 DESCRIPTION
 
@@ -249,22 +249,22 @@ A path to a C<UNIX> socket used to communicate between the publishers. By defaul
 
 =head1 HELPERS
 
-=head2 publish
+=head2 pubsub->publish
 
-  $c->publish("message");
-  $c->publish(@args);
+  $c->pubsub->publish("message");
+  $c->pubsub->publish(@args);
 
 Publishes a message that the subscribing callbacks will receive.
 
-=head2 subscribe
+=head2 pubsub->subscribe
 
-  $c->subscribe($cb);
+  $c->pubsub->subscribe($cb);
 
 Add the C<$cb> code reference to the callbacks that get published messages.
 
-=head2 unsubscribe
+=head2 pubsub->unsubscribe
 
-  $c->unsubscribe($cb);
+  $c->pubsub->unsubscribe($cb);
 
 Remove the C<$cb> code reference from the callbacks that get published messages.
 
@@ -275,7 +275,7 @@ Remove the C<$cb> code reference from the callbacks that get published messages.
     ...
   };
 
-Subscribers sent to the C<cb> option, or the C<subscribe> helper should simply be C<CODE> references that handle the arguments passed in. The C<@args> will be the same as what was passed in to the C<publish> helper, except they will have gotten C<JSON> encoded via L<Mojo::JSON> on the way, so only data structures that consist of regular scalars, arrays, hashes, and objects that implement C<TO_JSON> or that stringify will work correctly. See L<Mojo::JSON> for more details.
+Subscribers sent to the C<cb> option, or the C<< pubsub->subscribe >> helper should simply be C<CODE> references that handle the arguments passed in. The C<@args> will be the same as what was passed in to the C<< pubsub->publish >> helper, except they will have gotten C<JSON> encoded via L<Mojo::JSON> on the way, so only data structures that consist of regular scalars, arrays, hashes, and objects that implement C<TO_JSON> or that stringify will work correctly. See L<Mojo::JSON> for more details.
 
 =head1 METHODS
 
